% calculate choice probability by uncertainty level, include or exclude $5 trials

clearvars

fixedButton = 0;

fixed_value = 5;
fixed_prob = 0.5;

value = [5 9.5 18 34 65];
ambig = [.24 .50 .74];
prob = [.38 .25 .13];
jitter = 0;

otherButton = 1;
noResponse = 2;

% change if move to other folder
thisdir = pwd;
path = [ thisdir '\'];

subjects1 = dir([path '*.txt']);
subjects = cell(1,length(subjects1));
for i = 1:length(subjects)
    subjects{i} = subjects1(i).name;
end



rtByUncertaintyFile = [path 'RJ_All_rt.xls'];
dlmwrite(rtByUncertaintyFile, [prob,prob,ambig,ambig], '-append', 'coffset', 1, 'delimiter', '\t');  


for s = 1:length(subjects)
    
    subject = subjects{s}
    filename = [path subject]

    trials2Use = 1:360;
    trialGroups = [1 180 181 360]; %  before and after intervention
    [vA_all,pA_all,AL_all,rt_all,choice_lottery_temp] = getChoicesEprimeLogBehavior_ambigChange(filename);
    
    % correct the ambiguity level
    AL_all(AL_all == 0.25) = 0.24;
    AL_all(AL_all == 0.75) = 0.74;
    
    choice_lottery_all = zeros(size(choice_lottery_temp));
    choice_lottery_all(find(choice_lottery_temp==noResponse)) = 2; 
    choice_lottery_all(find(choice_lottery_temp==fixedButton)) = 0;
    choice_lottery_all(find(choice_lottery_temp==otherButton)) = 1;
    
    riskByUncert = zeros(2,length(prob));
    ambigByUncert = zeros(2,length(ambig));
        
    for m = 1:2
        % 1: before intervention; 2: after intervention
        % before intervention: 1-180, after intervention: 181-360
        vA = vA_all(trialGroups(2*m-1):trialGroups(2*m));
        pA = pA_all(trialGroups(2*m-1):trialGroups(2*m));
        AL = AL_all(trialGroups(2*m-1):trialGroups(2*m));
        rt = rt_all(trialGroups(2*m-1):trialGroups(2*m));
        choice_lottery = choice_lottery_all(trialGroups(2*m-1):trialGroups(2*m));

       % actual choices
        choice_orig = choice_lottery;

        % get rid of no choice trials
        choice = choice_orig(find(choice_orig~=2));
        vA = vA(find(choice_orig~=2));
        AL = AL(find(choice_orig~=2));
        pA = pA(find(choice_orig~=2));
        rt = rt(find(choice_orig~=2));
                                
        
        % do not include $5 trials 
        choice = choice(find(vA~=5));
        AL = AL(find(vA~=5));
        pA = pA(find(vA~=5));
        rt = rt(find(vA~=5));
        vA = vA(find(vA~=5));
                
        % calculate risk choice prob by risk level
        riskByUncert(m,:) = [sum(rt(pA==prob(1) & AL==0))/length(rt(pA==prob(1) & AL==0)),...
            sum(rt(pA==prob(2) & AL==0))/length(rt(pA==prob(2) & AL==0)),...
            sum(rt(pA==prob(3) & AL==0))/length(rt(pA==prob(3) & AL==0))];
        
        ambigByUncert(m,:) = [sum(rt(AL==ambig(1)))/length(rt(AL==ambig(1))),...
            sum(rt(AL==ambig(2)))/length(rt(AL==ambig(2))),...
            sum(rt(AL==ambig(3)))/length(rt(AL==ambig(3)))];

    end
 
        dlmwrite(rtByUncertaintyFile, [str2num(subject(1:length(subject)-4)),...
                                           riskByUncert(1,:),riskByUncert(2,:),...
                                           ambigByUncert(1,:),ambigByUncert(2,:)],...                                           
                                           '-append', 'delimiter', '\t');                  
end
